#!/bin/sh

set -e
# set -x

CURDIR=`pwd`
TARGET=$1
IMINVER=$2
IMAXVER=$3
UPSTREAM_VERSION=$4
DEB_VERSION=$5
LOWER="sed --posix y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/"
EXTDIR="/usr/lib/iceweasel/extensions"
DSETDIR="/var/lib/iceweasel/extensions.d"

IMINVER=`echo $IMINVER|sed 's/~//'`
IMAXVER=`echo $IMAXVER|sed 's/~//'`

patch_ru_locale()
{
    TMP_DIR=`mktemp -d`
    RP=`find ru -name region.properties|grep browser-region`
    test -f $RP
    echo "Replace russian region properties"
    cp $CURDIR/debian/replaces/ru.region.properties $RP
}

override_dh_auto_build()
{
    cd $CURDIR/upstream
    mkdir $CURDIR/build
    for XPI in *.xpi; do
    	LOCALE=`basename $XPI .xpi`
    	xpi-unpack $XPI $CURDIR/build/$LOCALE
        
        cd $CURDIR/build/
    	
    	brand_dtd=`find $LOCALE -name brand.dtd|grep branding`
    	brand_properties=`find $LOCALE -name brand.properties|grep branding`

        sed -i  -e 's|brandShortName.*|brandShortName "Iceweasel">|' \
                -e 's|brandFullName.*|brandFullName "Iceweasel">|' \
                    $brand_dtd
        sed -i  -e 's|brandShortName.*|brandShortName=Iceweasel|' \
                -e 's|brandFullName.*|brandFullName=Iceweasel|' \
                    $brand_properties
        
        sed -i -e "/./,\$ !d; s/em:maxVersion>.*</em:maxVersion>$IMAXVER</" \
            $LOCALE/install.rdf
        sed -i -e "/./,\$ !d; s/em:minVersion>.*</em:minVersion>$IMINVER</" \
            $LOCALE/install.rdf
        
        if test -d $CURDIR/debian/patches; then
            if ls $CURDIR/debian/patches|grep -qi ^$LOCALE'\.'; then
                for patch in $CURDIR/debian/patches/$LOCALE.*patch; do
                    echo applying patch $patch
                    patch -d $CURDIR -p0 < $patch
                done
            fi
        fi

        if test $LOCALE = ru; then
            patch_ru_locale
        fi

        # validation
        xmlstarlet val $CURDIR/build/$LOCALE/install.rdf

        xpi-pack $LOCALE $LOCALE.xpi

        ID=`cat $LOCALE/install.rdf \
            |sed --posix '/em:id=/!d;s/[ ]*em:id="//;s/".*//'`

        echo $ID > $LOCALE/id.txt
        cd $CURDIR/upstream
    done
}

override_dh_auto_install()
{
    cd $CURDIR/build

    for XPI in *.xpi; do
    	LOCALE=`basename $XPI .xpi`
    	LANGUAGE=`echo $LOCALE | $LOWER`
    	ID=`cat $LOCALE/id.txt`
    	install -D -m 0644 $XPI \
    	    $CURDIR/debian/iceweasel-l10n-$LANGUAGE/$EXTDIR/$ID.xpi

    done
}

umask 022   # for mkdirs
$TARGET
